import _extends from "@babel/runtime/helpers/esm/extends";
import { jsx as _jsx } from "react/jsx-runtime";
import React from 'react';
import cx from 'classnames';
import ActionableTag from './Actionable';
import StandardTag from './Standard';
var ACTIONABLE_ONLY_PROPS = ['href', 'iconPlacement', 'target', 'actionable', 'linkFactory', 'rel'];
var STANDARD_ONLY_PROPS = ['closeIcon', 'onClose'];
var SIZES = {
  LARGE: 'large',
  MEDIUM: 'medium',
  SMALL: 'small'
};
var LINK_TYPES = {
  NOFOLLOW: 'nofollow',
  NOOPENER: 'noopener',
  NOREFERRER: 'noreferrer',
  PREV: 'prev',
  NEXT: 'next',
  TAG: 'tag'
};
export var DESIGNS = {
  SOLID: 'solid',
  OUTLINE: 'outline'
};
/**
 * returns key:value in obj except for those keys defined in props
 * @param {Object} obj
 * @param {Array.<string>} props
 * @return {Object}
 */

var filterKeys = function filterKeys(obj, listOfProps) {
  return Object.keys(obj).reduce(function (acc, key) {
    if (listOfProps.indexOf(key) === -1) {
      acc[key] = obj[key];
    }

    return acc;
  }, {});
};

var AtomTag = function AtomTag(props) {
  var design = props.design,
      href = props.href,
      icon = props.icon,
      onClick = props.onClick,
      responsive = props.responsive,
      size = props.size,
      type = props.type;
  var isActionable = onClick || href;
  var classNames = cx('sui-AtomTag', "sui-AtomTag-" + size, design && "sui-AtomTag--" + design, icon && 'sui-AtomTag-hasIcon', responsive && 'sui-AtomTag--responsive', type && "sui-AtomTag--" + type);
  /**
   * Removes all actionable tag props from the react props
   * @return {Object}
   */

  var getStandardProps = function getStandardProps() {
    return filterKeys(props, ACTIONABLE_ONLY_PROPS);
  };
  /**
   * Removes all standard tag props from the react props
   * @return {Object}
   */


  var getActionableProps = function getActionableProps() {
    return filterKeys(props, STANDARD_ONLY_PROPS);
  };

  return isActionable ? /*#__PURE__*/_jsx(ActionableTag, _extends({}, getActionableProps(), {
    className: classNames
  })) : /*#__PURE__*/_jsx(StandardTag, _extends({}, getStandardProps(), {
    className: classNames
  }));
};

AtomTag.displayName = 'AtomTag';
AtomTag.defaultProps = {
  iconPlacement: 'left'
};
AtomTag.defaultProps = {
  size: SIZES.MEDIUM
};
export default AtomTag;
export { DESIGNS as atomTagDesigns };
export { LINK_TYPES as linkTypes };
export { SIZES as atomTagSizes };